@@ -1,14 +1,12 @@
 from __future__ import print_function
 
 import argparse
+import io
+import json
 import sys
-import simplejson
-
-from pre_commit_hooks.util import entry
 
 
-@entry
-def check_json(argv):
+def check_json(argv=None):
     parser = argparse.ArgumentParser()
     parser.add_argument('filenames', nargs='*', help='JSON filenames to check.')
     args = parser.parse_args(argv)
@@ -16,9 +14,9 @@ def check_json(argv):
     retval = 0
     for filename in args.filenames:
         try:
-            simplejson.load(open(filename))
-        except simplejson.JSONDecodeError as e:
-            print('{0}: Failed to json encode ({1})'.format(filename, e))
+            json.load(io.open(filename, encoding='UTF-8'))
+        except (ValueError, UnicodeDecodeError) as exc:
+            print('{}: Failed to json decode ({})'.format(filename, exc))
             retval = 1
     return retval
 
