@@ -6,10 +6,8 @@ import ast
 import collections
 import traceback
 
-from pre_commit_hooks.util import entry
 
-
-DEBUG_STATEMENTS = set(['pdb', 'ipdb', 'pudb'])
+DEBUG_STATEMENTS = {'pdb', 'ipdb', 'pudb', 'q', 'rdb'}
 
 
 DebugStatement = collections.namedtuple(
@@ -31,15 +29,15 @@ class ImportStatementParser(ast.NodeVisitor):
     def visit_ImportFrom(self, node):
         if node.module in DEBUG_STATEMENTS:
             self.debug_import_statements.append(
-                DebugStatement(node.module, node.lineno, node.col_offset)
+                DebugStatement(node.module, node.lineno, node.col_offset),
             )
 
 
 def check_file_for_debug_statements(filename):
     try:
-        ast_obj = ast.parse(open(filename).read(), filename=filename)
+        ast_obj = ast.parse(open(filename, 'rb').read(), filename=filename)
     except SyntaxError:
-        print('{0} - Could not parse ast'.format(filename))
+        print('{} - Could not parse ast'.format(filename))
         print()
         print('\t' + traceback.format_exc().replace('\n', '\n\t'))
         print()
@@ -49,20 +47,19 @@ def check_file_for_debug_statements(filename):
     if visitor.debug_import_statements:
         for debug_statement in visitor.debug_import_statements:
             print(
-                '{0}:{1}:{2} - {3} imported'.format(
+                '{}:{}:{} - {} imported'.format(
                     filename,
                     debug_statement.line,
                     debug_statement.col,
                     debug_statement.name,
-                )
+                ),
             )
         return 1
     else:
         return 0
 
 
-@entry
-def debug_statement_hook(argv):
+def debug_statement_hook(argv=None):
     parser = argparse.ArgumentParser()
     parser.add_argument('filenames', nargs='*', help='Filenames to run')
     args = parser.parse_args(argv)
